@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
-our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-27'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,15 +15,6 @@ our @EXPORT_OK = qw(gen_perinci_cmdline_completer_script);
 
 our %SPEC;
 
-sub _dump {
-    require Data::Dumper;
-    local $Data::Dumper::Deparse = 1;
-    local $Data::Dumper::Terse = 1;
-    my $res = Data::Dumper::Dumper($_[0]);
-    $res =~ s/\R\z//;
-    $res;
-}
-
 sub _pa {
     state $pa = do {
         require Perinci::Access::Lite;
@@ -286,13 +277,13 @@ sub gen_perinci_cmdline_completer_script {
                 (map {"require $_;\n"} @{$args{load_modules}}),
                 "\n") : ()),
 
-            'my $args = ', _dump(\%args), ";\n\n",
+            'my $args = ', dmp(\%args), ";\n\n",
 
-            'my $meta = ', _dump($meta), ";\n\n",
+            'my $meta = ', dmp($meta), ";\n\n",
 
-            'my $sc_metas = ', _dump($sc_metas), ";\n\n",
+            'my $sc_metas = ', dmp($sc_metas), ";\n\n",
 
-            'my $copts = ', _dump($cli->common_opts), ";\n\n",
+            'my $copts = ', dmp($cli->common_opts), ";\n\n",
 
             'my $r = {};', "\n\n",
 
@@ -459,14 +450,14 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.04 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
+This document describes version 0.05 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-09-27.
 
 =head1 FUNCTIONS
 
 
 =head2 gen_perinci_cmdline_completer_script(%args) -> [status, msg, result, meta]
 
-{en_US Generate Perinci::CmdLine completer script}.
+Generate Perinci::CmdLine completer script.
 
 Arguments ('*' denotes required arguments):
 
@@ -478,29 +469,29 @@ Arguments ('*' denotes required arguments):
 
 =item * B<exclude_package_functions_match> => I<re>
 
-{en_US Exclude package functions matching this pattern}.
+Exclude package functions matching this pattern.
 
 =item * B<get_subcommand_from_arg> => I<int> (default: 1)
 
 =item * B<include_package_functions_match> => I<re>
 
-{en_US Only include package functions matching this pattern}.
+Only include package functions matching this pattern.
 
 =item * B<interpreter_path> => I<str>
 
-{en_US What to put on shebang line}.
+What to put on shebang line.
 
 =item * B<load_module> => I<array[str]>
 
-{en_US Load extra modules}.
+Load extra modules.
 
 =item * B<output_file> => I<str> (default: "-")
 
-{en_US Path to output file}.
+Path to output file.
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-{en_US Whether to overwrite output if previously exists}.
+Whether to overwrite output if previously exists.
 
 =item * B<per_arg_json> => I<bool>
 
@@ -508,7 +499,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<program_name>* => I<str>
 
-{en_US Program name that is being completed}.
+Program name that is being completed.
 
 =item * B<read_config> => I<bool>
 
@@ -518,9 +509,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<subcommand> => I<array[str]>
 
-{en_US Subcommand name followed by colon and function URL}.
+Subcommand name followed by colon and function URL.
 
-{en_US 
 Optionally, it can be additionally followed by a summary, so:
 
  NAME:URL[:SUMMARY]
@@ -529,13 +519,10 @@ Example (on CLI):
 
  --subcommand "delete:/My/App/delete_item:Delete an item"
 
-}
-
 =item * B<subcommands_from_package_functions> => I<bool>
 
-{en_US Form subcommands from functions under package's URL}.
+Form subcommands from functions under package's URL.
 
-{en_US 
 This is an alternative to the C<subcommand> option. Instead of specifying each
 subcommand's name and URL, you can also specify that subcommand names are from
 functions under the package URL in C<url>. So for example if C<url> is C</My/App/>,
@@ -551,11 +538,9 @@ then the subcommands become:
  bar => /My/App/bar
  "baz-qux" => /My/App/baz_qux
 
-}
-
 =item * B<url>* => I<str>
 
-{en_US URL to function (or package, if you have subcommands)}.
+URL to function (or package, if you have subcommands).
 
 =back
 
